==> qtjambi-quick-debuginfo-macos-5.15.17.jar: sources/QtJambiQuick/QSGGeometry_TexturedPoint2D_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick/qsggeometry.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiQuick/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QSGGeometry_TexturedPoint2D(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSGGeometry::TexturedPoint2D")
    QSGGeometry::TexturedPoint2D *_ptr = reinterpret_cast<QSGGeometry::TexturedPoint2D *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QSGGeometry_TexturedPoint2D_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QSGGeometry::TexturedPoint2D *__qt_this = new(__qtjambi_ptr) QSGGeometry::TexturedPoint2D();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QSGGeometry::TexturedPoint2D
void __qt_destruct_QSGGeometry_TexturedPoint2D(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSGGeometry::TexturedPoint2D")
    reinterpret_cast<QSGGeometry::TexturedPoint2D*>(ptr)->~TexturedPoint2D();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSGGeometry::TexturedPoint2D::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_initialize_1native__Lio_qt_quick_QSGGeometry_00024TexturedPoint2D_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGGeometry::TexturedPoint2D::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSGGeometry_TexturedPoint2D_0, sizeof(QSGGeometry::TexturedPoint2D), typeid(QSGGeometry::TexturedPoint2D), false, &deleter_QSGGeometry_TexturedPoint2D, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSGGeometry::TexturedPoint2D::operator==(QSGGeometry::TexturedPoint2D,QSGGeometry::TexturedPoint2D)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_operator_1equal_1native_1cref_1QSGGeometry_1TexturedPoint2D__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGGeometry::TexturedPoint2D::operator==(QSGGeometry::TexturedPoint2D,QSGGeometry::TexturedPoint2D)", __qt_this)
        const QSGGeometry::TexturedPoint2D& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QSGGeometry::TexturedPoint2D>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGGeometry::TexturedPoint2D::set(float,float,float,float)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_set_1native_1float_1float_1float_1float__JFFFF)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jfloat nx0,
 jfloat ny1,
 jfloat ntx2,
 jfloat nty3)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGGeometry::TexturedPoint2D::set(float,float,float,float)", __qt_this)
        __qt_this->set(static_cast<float>(nx0), static_cast<float>(ny1), static_cast<float>(ntx2), static_cast<float>(nty3));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_setTx_1native_1float__JF)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jfloat tx0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->tx = static_cast<float>(tx0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jfloat JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_tx_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jfloat __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        float  __qt_value = __qt_this->tx;
        __java_return_value = jfloat(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_setTy_1native_1float__JF)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jfloat ty0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->ty = static_cast<float>(ty0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jfloat JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_ty_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jfloat __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        float  __qt_value = __qt_this->ty;
        __java_return_value = jfloat(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_setX_1native_1float__JF)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jfloat x0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->x = static_cast<float>(x0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jfloat JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_x_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jfloat __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        float  __qt_value = __qt_this->x;
        __java_return_value = jfloat(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_setY_1native_1float__JF)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jfloat y0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->y = static_cast<float>(y0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jfloat JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_y_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jfloat __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        float  __qt_value = __qt_this->y;
        __java_return_value = jfloat(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QSGGeometry_TexturedPoint2D(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QSGGeometry::TexturedPoint2D>("QSGGeometry::TexturedPoint2D", "io/qt/quick/QSGGeometry$TexturedPoint2D");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QSGGeometry_TexturedPoint2D, {
        ConstructorInfo(&__qt_construct_QSGGeometry_TexturedPoint2D_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSGGeometry_TexturedPoint2D);
    registerMetaType<QSGGeometry::TexturedPoint2D>("QSGGeometry::TexturedPoint2D");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-quick-debuginfo-macos-5.15.18.jar: sources/QtJambiQuick/QSGGeometry_TexturedPoint2D_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick/qsggeometry.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiQuick/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QSGGeometry_TexturedPoint2D(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSGGeometry::TexturedPoint2D")
    QSGGeometry::TexturedPoint2D *_ptr = reinterpret_cast<QSGGeometry::TexturedPoint2D *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QSGGeometry_TexturedPoint2D_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QSGGeometry::TexturedPoint2D *__qt_this = new(__qtjambi_ptr) QSGGeometry::TexturedPoint2D();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QSGGeometry::TexturedPoint2D
void __qt_destruct_QSGGeometry_TexturedPoint2D(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSGGeometry::TexturedPoint2D")
    reinterpret_cast<QSGGeometry::TexturedPoint2D*>(ptr)->~TexturedPoint2D();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSGGeometry::TexturedPoint2D::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_initialize_1native__Lio_qt_quick_QSGGeometry_00024TexturedPoint2D_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGGeometry::TexturedPoint2D::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSGGeometry_TexturedPoint2D_0, sizeof(QSGGeometry::TexturedPoint2D), typeid(QSGGeometry::TexturedPoint2D), false, &deleter_QSGGeometry_TexturedPoint2D, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSGGeometry::TexturedPoint2D::operator==(QSGGeometry::TexturedPoint2D,QSGGeometry::TexturedPoint2D)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_equals_1native_1cref_1QSGGeometry_1TexturedPoint2D__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGGeometry::TexturedPoint2D::operator==(QSGGeometry::TexturedPoint2D,QSGGeometry::TexturedPoint2D)", __qt_this)
        const QSGGeometry::TexturedPoint2D& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QSGGeometry::TexturedPoint2D>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGGeometry::TexturedPoint2D::set(float,float,float,float)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_set_1native_1float_1float_1float_1float__JFFFF)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jfloat nx0,
 jfloat ny1,
 jfloat ntx2,
 jfloat nty3)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGGeometry::TexturedPoint2D::set(float,float,float,float)", __qt_this)
        __qt_this->set(static_cast<float>(nx0), static_cast<float>(ny1), static_cast<float>(ntx2), static_cast<float>(nty3));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_setTx_1native_1float__JF)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jfloat tx0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->tx = static_cast<float>(tx0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jfloat JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_tx_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jfloat __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        float  __qt_value = __qt_this->tx;
        __java_return_value = jfloat(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_setTy_1native_1float__JF)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jfloat ty0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->ty = static_cast<float>(ty0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jfloat JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_ty_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jfloat __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        float  __qt_value = __qt_this->ty;
        __java_return_value = jfloat(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_setX_1native_1float__JF)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jfloat x0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->x = static_cast<float>(x0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jfloat JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_x_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jfloat __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        float  __qt_value = __qt_this->x;
        __java_return_value = jfloat(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_setY_1native_1float__JF)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jfloat y0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->y = static_cast<float>(y0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jfloat JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_y_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jfloat __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        float  __qt_value = __qt_this->y;
        __java_return_value = jfloat(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024TexturedPoint2D_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QSGGeometry::TexturedPoint2D *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::TexturedPoint2D>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QSGGeometry_TexturedPoint2D(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QSGGeometry::TexturedPoint2D>("QSGGeometry::TexturedPoint2D", "io/qt/quick/QSGGeometry$TexturedPoint2D");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QSGGeometry_TexturedPoint2D, {
        ConstructorInfo(&__qt_construct_QSGGeometry_TexturedPoint2D_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSGGeometry_TexturedPoint2D);
    registerMetaType<QSGGeometry::TexturedPoint2D>("QSGGeometry::TexturedPoint2D");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
